/* prerequisites */
new;
library maxlik, pgraph;
#include maxlik.ext;
#include indices.src;
maxset;
format /rd 12,4 ;

/* set global MAXLIK variables */
_max_Algorithm  = 5		; /* see MAXLIK manual, p. 42 */
_max_LineSearch = 1		; /* see MAXLIK manual, p. 45 */
_max_CovPar 	= 1		; /* see MAXLIK manual, p. 42 */
_max_gradtol	= 1e-5 	; /* see MAXLIK manual, p. 43 */
_max_GradMethod	= 1		; /* see MAXLIK manual, p. 43 */
_max_MaxIters   = 500  ; /* see MAXLIK manual, p. 45 */

output file = e:\ibe_uka\progs\grup.out reset ;

/* COMPLETE DATA SET */
open f1 	= e:\ibe_uka\data\prepared varindxi ;
mat   		= readr(f1, rowsf(f1));

/* all variables */
/* first variable is the dependent in level equation
   second variable is dependent in selection equation 
   the variables after the constant (ones) are the
   identifiers */
mat			=   
				mat[.,iln_yl  ]~mat[.,igrup   ]~
				mat[.,iln_it  ]~mat[.,iln_k   ]~mat[.,iln_l   ]~
				mat[.,iedv    ]~mat[.,iste    ]~mat[.,iunt    ]~
				mat[.,iarc    ]~mat[.,ipla    ]~mat[.,iwer    ]~
				mat[.,ikfz    ]~mat[.,imas    ]~mat[.,ispe    ]~
				mat[.,iost    ]~ones(rows(mat),1)~
				mat[.,iexpo   ]~mat[.,ikonk   ]~mat[.,iaus    ]~
				mat[.,isaldo2 ]~mat[.,isaldo3 ];

/* skip outliers */
mat			= selif(mat, mat[.,1].>  1.609438  );  
mat			= selif(mat, mat[.,1].<    8.160519   );  


mat			= packr(mat);

/* name of dependent in level equation */
dep1		= { ln_yl };
/* name of dependent in selecton equation */
dep2		= { team  };
/* name of identifiers */
namident	= { expo , konk , aus ,  saldo2 , saldo3  };
noident		= rows(namident);
/* name of variables in selection equation (first is the dependent) */
namprod		= { ln_yl,
				ln_it, ln_k,ln_l, 
				edv  , ste, unt,
				arc  , pla, wer,
				kfz  , mas, spe,
				ost , cons };

namorg		= dep2|namident|namprod[2:rows(namprod)];

y1			= mat[.,1];
y2			= mat[.,2];

x			= mat[.,3:cols(mat)-noident];
ident		= mat[.,cols(mat)-noident+1:cols(mat)];
z			= ident~x;

prod		= y1~x;
org			= y2~z;

matn		= prod~org;

names 		= namprod|namorg;

/* FULL DATA SET */
create full	= e:\ibe_uka\data\full with ^names,0,8;
call			  writer(full,matn);

/****************************************************/
/* 					STARTING VALUES 				*/
/****************************************************/
/********************/
/* 1. BINARY PROBIT */
/********************/
_max_ParNames   = namorg[2:rows(namorg)];
bin_names		= namorg;
b0				= zeros(rows(bin_names)-1,1)+.1;
b0				= inv(z'*z)*z'*y2;
{bbinary,f,g,cov,ret}=maxlik("e:\\ibe_uka\\data\\full",bin_names,&probit,b0);
call maxprt(bbinary,f,g,cov,ret) ;

/* Test for heteroscedasticity */
indepvar		= z;
depvar			= y2;
xb				= indepvar*bbinary;
genres			= (depvar-cdfn(xb))./(cdfn(xb).*(1-cdfn(xb))).*pdfn(xb);
egx				= (genres.*indepvar);
egxbz			= genres.*xb.*indepvar;
indepvar		= egx~egxbz;
depvar			= ones(rows(depvar),1);
btest			= inv(indepvar'*indepvar)*indepvar'*depvar;
fit				= indepvar*btest;
res				= depvar-fit;
N				= rows(xb);
K				= rows(btest);
r2				= 1-(( res'*res )/( depvar'*depvar ));
J				= cols(indepvar)/2;
print"";
print"LM-Test for heteroscedasticity, p-value";
(N*r2)~cdfchic(N*r2,J);


/* Test for normality*/
indepvar		= z;
depvar			= y2;
xb				= indepvar*bbinary;
genres			= (depvar-cdfn(xb))./(cdfn(xb).*(1-cdfn(xb))).*pdfn(xb);
egx				= (genres.*z);
egxb2			= genres.*(xb^2);
indepvar		= egx~egxb2;
depvar			= ones(rows(depvar),1);
btest			= inv(indepvar'*indepvar)*indepvar'*depvar;
fit				= indepvar*btest;
res				= depvar-fit;
N				= rows(y2);
K				= rows(btest);
r2				= 1-(( res'*res )/( depvar'*depvar ));
J				= cols(indepvar)/2;
print"";
print"LM-Test for normality, p-value";
(N*r2)~cdfchic(N*r2,2);

/* goodness-of-fit */
probitfit		= (z)*bbinary;
N1				= sumc(y2.==1);
N				= rows(y2);
l0				= N1*ln(N1/N)+(N-N1)*ln(1-(N1/N));
l1				= f*N;
mcf				= 1-l1/l0;
lr				= 2*(l1-l0);
print"";
print"Test for joint significancy and p-value";
lr~cdfchic(lr,cols(bbinary));
print"";
print"McFadden pseudo R2";
mcf;

/*********************************/
/* 2. HECKMAN SELECTION EQUATION */
/*********************************/
m1			= pdfn(z*bbinary)./cdfn(z*bbinary);
delta1		= m1.*(m1+z*bbinary);
delta1		= delta1.*(y2.==1);
delta1		= delif(delta1,delta1.==0);
x1			= (x~m1).*(y2.==1);
x1			= delif(x1,x1[.,cols(x1)].==0);
y			= y1.*(y2.==1);
y			= delif(y,y.==0);
bhat1		= inv(x1'*x1)*x1'*y;
e1			= y-x1*bhat1;
sigma1		= sqrt((e1'*e1 + bhat1[rows(bhat1)]*sumc(delta1))/(rows(y1)));

m2			= pdfn(-z*bbinary)./cdfn(-z*bbinary);
delta2		= m2.*(m1-z*bbinary);
delta2		= delta2.*(y2.==0);
delta2		= delif(delta2,delta2.==0);
x2			= (x~m2).*(y2.==0);
x2			= delif(x2,x2[.,cols(x2)].==0);
y			= y1.*(y2.==0);
y			= delif(y,y.==0);
bhat2		= inv(x2'*x2)*x2'*y;
e2			= y-x2*bhat2;
sigma2		= sqrt((e2'*e2 + bhat2[rows(bhat2)]*sumc(delta2))/(rows(y)));

rho1		= -.3;
rho2		= -.4;

/********************************************/
/*   FULL IMFORMATION MAXIMUM LIKELIHOOD	*/
/********************************************/
hv1				= { rho1  , rho2 };
hv2				= { sigma1, sigma2 };

_max_ParNames   = namprod[2:rows(namprod)]|namprod[2:rows(namprod)]|namorg[2:rows(namorg)]|
				  hv1|hv2;

bhat1			= bhat1[1:rows(bhat1)-1];
bhat2			= bhat2[1:rows(bhat2)-1];

rho1			=  -.7293329;
rho2			= -.1566286 ;
sigma1			= 1.121519 ;
sigma2			= .9830089;

b0				= bhat1|bhat2|bbinary|rho1|rho2|sigma1|sigma2;
  
est_names		= namprod|namorg;

_max_CovPar 	= 3		; /* see MAXLIK manual, p. 42 */
_max_Algorithm  = 2		; /* see MAXLIK manual, p. 42 */
{bswitch,f,g,cov,ret}=maxlik("e:\\ibe_uka\\data\\full",est_names,&switch,b0);

print"";
print"";
print"Das sind die Ergebnisse fuer den Fall, dass Gruppenarbeit eingefuehrt wurden";
call maxprt(bswitch,f,g,cov,ret) ;
print"";
print"";

no_level		= rows(namprod)-1;
no_select		= rows(namorg)-1;
switch_cov		= cov;
beta1			= bswitch[1:rows(namprod)-1];
beta2			= bswitch[rows(beta1)+1:rows(namprod)+rows(namprod)-2];
gam				= bswitch[rows(beta1)+rows(beta2)+1:rows(bswitch)-4];

cov1			= cov[1:no_level,1:no_level];
cov2			= cov[no_level+1:no_level*2,no_level+1:no_level*2];
cov_gam			= cov[no_level*2+1:no_level*2+no_select,no_level*2+1:no_level*2+no_select];


print"";
print"elasticity of labor; std. err.; p-val.";
print"with   :" 1+beta1[3]~sqrt(cov1[3,3])~cdfnc((1+abs(beta1[3])/sqrt(cov1[3,3])));
print"without:" 1+beta2[3]~sqrt(cov2[3,3])~cdfnc((1+abs(beta2[3])/sqrt(cov2[3,3])));
print"";
print"elasticity of IT; std. err.; p-val.";
print"with   :" beta1[1]~sqrt(cov1[1,1])~cdfnc(abs(beta1[1]/sqrt(cov1[1,1])));
print"without:" beta2[1]~sqrt(cov2[1,1])~cdfnc(abs(beta2[1]/sqrt(cov2[1,1])));
print"";
print"elasticity of K; std. err.; p-val.";
print"with   :" beta1[2]~sqrt(cov1[2,2])~cdfnc(abs(beta1[2]/sqrt(cov1[2,2])));
print"without:" beta2[2]~sqrt(cov2[2,2])~cdfnc(abs(beta2[2]/sqrt(cov2[2,2])));

print"";
print"Differences in productivities";
prod_mit		= x*beta1;
prod_ohn		= x*beta2;
print"                  w/ org       w/o org";
print"mean       :"  meanc(prod_mit)~meanc(prod_ohn);
print"median     :" median(prod_mit)~median(prod_ohn);
print"std. err.  :" stdc(prod_mit)~stdc(prod_ohn);

hv				= y2~x;
xoc				= selif(hv, hv[.,1].==0);
xoc				= xoc[.,2:cols(xoc)];
xnoc			= selif(hv, hv[.,1].==1);
xnoc			= xnoc[.,2:cols(xnoc)];

xoc_boc  		= xoc *beta1;
xoc_bno 		= xoc *beta2;
hv				= ones(rows(x)-rows(xoc),1)*(-999);
xoc_boc			= xoc_boc|hv;
xoc_bno			= xoc_bno|hv;

xnoc_boc  		= xnoc*beta1;
xnoc_bno  		= xnoc*beta2;
hv				= ones(rows(x)-rows(xnoc),1)*(-999);
xnoc_boc		= xnoc_boc|hv;
xnoc_bno		= xnoc_bno|hv;

matnn			=   xoc_boc~ xnoc_boc~ xoc_bno~ xnoc_bno 	 ;
namesn			= { xoc_boc, xnoc_boc, xoc_bno, xnoc_bno  };

closeall;
create grup		= e:\ibe_uka\data\grup with ^namesn,0,8;
call			  writer(grup,matnn);


xoc_boc			= selif(xoc_boc , xoc_boc.>-999);
xnoc_boc		= selif(xnoc_boc, xnoc_boc.>-999);
xoc_bno			= selif(xoc_bno , xoc_bno.>-999);
xnoc_bno		= selif(xnoc_bno, xnoc_bno.>-999);

print"";
print"***********************************************************";
print"Test of significant differences in productivity differences";
print"***********************************************************";
print"";

diff			= xoc_boc - xoc_bno;
mdiff			= meanc(xoc_boc - xoc_bno);
sdiff			= stdc(xoc_boc - xoc_bno);
print"      mean         t-val.       p-val.";
mdiff~mdiff/sdiff~cdfnc(abs(mdiff/sdiff));
print"";
diff			= xnoc_boc - xnoc_bno;
mdiff			= meanc(xnoc_boc - xnoc_bno);
sdiff			= stdc(xnoc_boc - xnoc_bno);
print"      mean         t-val.       p-val.";
mdiff~mdiff/sdiff~cdfnc(abs(mdiff/sdiff));


print"";
print"";
print"-------------------------------------------------";
print"Differences in productivity coefficients";
print"-------------------------------------------------";
alpha1			= beta1[1:3];
alpha2			= beta2[1:3];
covn			= (cov[1:3,1:3]~cov[1:3,15:17])|
				  (cov[15:17,1:3]~cov[15:17,15:17]);
theta			= alpha1|alpha2;
R				= eye(rows(alpha1))~(-eye(rows(alpha2)));
W				= (R*theta)'*inv(R*covn*R')*(R*theta);
print"difference" alpha1-alpha2;
print"entire parameter vector (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
print"";
print"-------------------------------------------------";
print"Differences in entire parameter vector";
print"-------------------------------------------------";
alpha1			= beta1[1:rows(beta1)];
alpha2			= beta2[1:rows(beta2)];
covn			= (cov[1:rows(beta1)+rows(beta2),1:rows(beta1)+rows(beta2)]);
theta			= alpha1|alpha2;
R				= eye(rows(alpha1))~(-eye(rows(alpha2)));
W				= (R*theta)'*inv(R*covn*R')*(R*theta);
print"difference" alpha1-alpha2;
print"entire parameter vector (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
print"";
print"-------------------------------------------------";
print"Differences in output elasticity w/ respect to IT";
print"-------------------------------------------------";
alpha1			= beta1[1];
alpha2			= beta2[1];
covn			= ( cov[1,         1]~cov[         1,no_level+1] )|
				  ( cov[1,no_level+1]~cov[no_level+1,no_level+1] );
theta			= alpha1|alpha2;
R				= eye(rows(alpha1))~(-eye(rows(alpha2)));
W				= (R*theta)'*inv(R*covn*R')*(R*theta);
print"alpha_org:" alpha1;; print"alpha_norg:" alpha2;
print"elasticity of IT (alpha) different across regimes? (Wald;p-value)";
W~cdfchic(W,rows(R));


print"";
print"------------------------------------------------------";
print"Differences in output elasticity w/ respect to capital";
print"------------------------------------------------------";
alpha1			= beta1[2];
alpha2			= beta2[2];
covn			= ( cov[2,         2]~cov[         2,no_level+2] )|
				  ( cov[2,no_level+2]~cov[no_level+2,no_level+2] );
theta			= alpha1|alpha2;
R				= eye(rows(alpha1))~(-eye(rows(alpha2)));
W				= (R*theta)'*inv(R*covn*R')*(R*theta);
print"beta_org:" alpha1;; print"beta_norg:" alpha2;
print"elasticity of capital (beta) different across regimes? (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
print"----------------------------------------------------";
print"Differences in output elasticity w/ respect to labor";
print"----------------------------------------------------";
alpha1			= beta1[3];
alpha2			= beta2[3];
covn			= ( cov[3,         3]~cov[         3,no_level+3] )|
				  ( cov[3,no_level+3]~cov[no_level+3,no_level+3] );
theta			= alpha1|alpha2;
R				= eye(rows(alpha1))~(-eye(rows(alpha2)));
W				= (R*theta)'*inv(R*covn*R')*(R*theta);
print"gamma_org:" alpha1;; print"gamma_norg:" alpha2;
print"elasticity of capital (gamma) different across regimes? (Wald;p-value)";
W~cdfchic(W,rows(R));


print"----------------------------------------------------";
print"IT-elasticity equal to capital-elasticity?          ";
print"----------------------------------------------------";
alpha1			= beta1[1];
alpha2			= beta1[2];
covn			= cov1[1:2,1:2];
theta			= alpha1|alpha2;
R				= eye(rows(alpha1))~(-eye(rows(alpha2)));
W				= (R*theta)'*inv(R*covn*R')*(R*theta);
print"regime w/ workplace reorg.";
print"IT-ela";;alpha1;;print"K-ela";;alpha2;
print"IT-elasticity equal to capital-elasticity?  (Wald;p-value)";
W~cdfchic(W,rows(R));

alpha1			= beta2[1];
alpha2			= beta2[2];
covn			= cov2[1:2,1:2];
theta			= alpha1|alpha2;
R				= eye(rows(alpha1))~(-eye(rows(alpha2)));
W				= (R*theta)'*inv(R*covn*R')*(R*theta);
print"regime w/o workplace reorg.";
print"IT-ela";;alpha1;;print"K-ela";;alpha2;
print"IT-elasticity equal to capital-elasticity?  (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
print"----------------------------------------------------";
print"Differences in sector dummies 					  ";
print"----------------------------------------------------";
alpha1			= beta1[4:12];
alpha2			= beta2[4:12];
covn			= ( cov[4:12, 4:12]~cov[ 4:12,no_level+4:no_level+12] )|
				  ( cov[no_level+4:no_level+12,4:12]~cov[no_level+4:no_level+12,no_level+4:no_level+12] );
theta			= alpha1|alpha2;
R				= eye(rows(alpha1))~(-eye(rows(alpha2)));
W				= (R*theta)'*inv(R*covn*R')*(R*theta);
print"difference in sector dummies";;alpha1-alpha2;
print"Sector dummies different across regimes? (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
print"----------------------------------------------------";
print"Differences East dummy variables                	  ";
print"----------------------------------------------------";
alpha1			= beta1[13];
alpha2			= beta2[13];
covn			= ( cov[13,13]~cov[13,no_level+13] )|
				  ( cov[no_level+13,13]~cov[no_level+13,no_level+13] );
theta			= alpha1|alpha2;
R				= eye(rows(alpha1))~(-eye(rows(alpha2)));
W				= (R*theta)'*inv(R*covn*R')*(R*theta);
print"difference in East dummies";;alpha1-alpha2;
print"East dummies different across regimes? (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
print"----------------------------------------------------";
print"Differences constant term		                	  ";
print"----------------------------------------------------";
alpha1			= beta1[rows(beta1)];
alpha2			= beta2[rows(beta1)];
covn			= ( cov[rows(beta1),rows(beta1)]~cov[rows(beta1),no_level+rows(beta1)] )|
				  ( cov[no_level+rows(beta1),rows(beta1)]~cov[no_level+rows(beta1),no_level+rows(beta1)] );
theta			= alpha1|alpha2;
R				= eye(rows(alpha1))~(-eye(rows(alpha2)));
W				= (R*theta)'*inv(R*covn*R')*(R*theta);
print"difference in constant terms";;alpha1-alpha2;
print"Constant terms different across regimes? (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
print"-------------------------------------------------";
print"Constant returns to scale?";
print"-------------------------------------------------";
alpha1			= beta1[1];
alpha2			= beta1[2];
alpha3			= 1+beta1[3];
covn			= cov[1:3,1:3];
theta			= alpha1|alpha2|alpha3;
R				= ones(rows(theta),1);
q				= 1;
W				= (theta'*R-q)'*inv(R'*covn*R)*(theta'*R-q);
print"sum of parameters:" alpha1+alpha2+alpha3;
print"Constant returns to scale w/ change? (p-value)";
W~cdfchic(W,rows(R));

alpha1			= beta2[1];
alpha2			= beta2[2];
alpha3			= 1+beta2[3];
covn			= cov2[1:3,1:3];
theta			= alpha1|alpha2|alpha3;
R				= ones(rows(theta),1);
q				= 1;
W				= (theta'*R-q)'*inv(R'*covn*R)*(theta'*R-q);
print"sum of parameters:" alpha1+alpha2+alpha3;
print"Constant returns to scale w/o change? (p-value)";
W~cdfchic(W,rows(R));


print"";
print"-------------------------------------------------";
print" Wald-tests for joint significancy ";
print"-------------------------------------------------";
print"";
print"Entire specification w/o constant";
theta		= beta1[1:rows(beta1)-1];
covn		= cov1[1:rows(beta1)-1,1:rows(beta1)-1];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"specification w/ change (Wald;p-value)";
W~cdfchic(W,rows(R));
theta		= beta2[1:rows(beta2)-1];
covn		= cov2[1:rows(beta2)-1,1:rows(beta2)-1];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"specification w/o change (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
print"factor inputs";
theta		= beta1[1:3];
covn		= cov1[1:3,1:3];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"specification w/ change (Wald;p-value)";
W~cdfchic(W,rows(R));
theta		= beta2[1:3];
covn		= cov2[1:3,1:3];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"specification w/o change (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
print"sector dumies";
theta		= beta1[4:12];
covn		= cov1[4:12,4:12];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"specification w/ change (Wald;p-value)";
W~cdfchic(W,rows(R));
print"w/o org. change";
theta		= beta2[4:12];
covn		= cov2[4:12,4:12];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"specification w/o change (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
theta		= bswitch[rows(bswitch)-3:rows(bswitch)-2];
covn		= cov[rows(bswitch)-3:rows(bswitch)-2,rows(bswitch)-3:rows(bswitch)-2];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"correlation coefficients (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
theta		= beta1[1:rows(beta1)-1]|beta2[1:rows(beta2)-1]|gam[1:rows(gam)-1];
/* aendern */
covn		= ( cov[ 1:13,1:13]~cov[ 1:13,15:27]~cov[ 1:13,29:46] )|
			  ( cov[15:27,1:13]~cov[15:27,15:27]~cov[15:27,29:46] )|
			  ( cov[29:46,1:13]~cov[29:46,15:27]~cov[29:46,29:46] );
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"entire parameter vector (constants excl.) (Wald;p-value)";
W~cdfchic(W,rows(R));


print"";
print"Selection equation";
theta		= gam[1:rows(gam)-1];
covn		= cov_gam[1:rows(gam)-1,1:rows(gam)-1];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"entire parameter vector (constants excl.) (Wald;p-value)";
W~cdfchic(W,rows(R));

theta		= gam[1:noident];
covn		= cov_gam[1:noident,1:noident];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"identifiers (Wald;p-value)";
W~cdfchic(W,rows(R));

theta		= gam[noident+1:noident+3];
covn		= cov_gam[noident+1:noident+3,noident+1:noident+3];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"input factors (Wald;p-value)";
W~cdfchic(W,rows(R));

theta		= gam[noident+3+1:noident+3+9];
covn		= cov_gam[noident+3+1:noident+3+9,noident+3+1:noident+3+9];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"sector dummies (Wald;p-value)";
W~cdfchic(W,rows(R));

/* aendern */
theta		= gam[4:5];
covn		= cov_gam[4:5,4:5];
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*covn*R')*(R*theta);
print"sales balances (Wald;p-value)";
W~cdfchic(W,rows(R));



print"";
b1			= beta1[1:2]|beta1[3]+1;
b2			= beta2[1:2]|beta2[3]+1;
b			= sumc(b1)-sumc(b2);
C			= 1~1~1~-1~-1~-1;
covn		= (cov[1:3,1:3])~(cov[1:3,rows(beta1)+1:rows(beta1)+3])|
			  (cov[rows(beta1)+1:rows(beta1)+3,1:3]~cov[rows(beta1)+1:rows(beta1)+3,rows(beta1)+1:rows(beta1)+3]);

vcn			= C*covn*C';


print"diff. in ret. to scale, t-val., p-val, std. err.";
b~sqrt(vcn)~b/sqrt(vcn)~cdfnc(abs(b/sqrt(vcn)));

print"";

theta		= b;
R			= eye(rows(theta));
W			= (R*theta)'*inv(R*vcn*R')*(R*theta);
print"sales balances (Wald;p-value)";
W~cdfchic(W,rows(R));

print"";
print"----------------------------------------------------";
print"Differences returns to scale	                	  ";
print"----------------------------------------------------";
alpha1			= beta1[1:3];
alpha2			= beta2[1:3];
covn			= ( cov[1:3,1:3]~cov[1:3,rows(beta1)+1:rows(beta1)+3] )|
				  ( cov[rows(beta1)+1:rows(beta1)+3,1:3]~cov[rows(beta1)+1:rows(beta1)+3,rows(beta1)+1:rows(beta1)+3] );
theta			= (alpha1|alpha2);
R				= 1~1~1~-1~-1~-1;
W				= (R*theta)'*inv(R*covn*R')*(R*theta);
print"returns to scale different across regimes? (Wald;p-value)";
W~cdfchic(W,rank(R));
print"";
R*theta;

proc switch(b,dat);
	local y1, y2, x, z, 
		  gam, beta1, beta2,
		  rho1  , rho2  , sigma1, sigma2, dp,
		  t1    , t2    , t3    ,
		  u1    , u2    , u3    ;

		y1		= dat[.,1];
		y2		= dat[.,rows(namprod)+1];

		x		= dat[.,2:rows(namprod)];
		z		= dat[.,  rows(namprod)+2:cols(dat)];

		beta1	= b[1:rows(namprod)-1               ];
		beta2	= b[  rows(namprod):rows(namprod)+rows(namprod)-2];

		gam		= b[rows(namprod)+rows(namprod)-1:rows(b)-4];

		rho1	= b[rows(b)-3];
		rho2	= b[rows(b)-2];

		sigma1	= b[rows(b)-1];
		sigma2	= b[rows(b)-0];

		t1 		= ln(cdfn((z*gam+(y1-x*beta1)*(rho1/sigma1))/(sqrt(1-rho1^2))));
		u1 		= ln(cdfn((-z*gam-(y1-x*beta2)*(rho2/sigma2))/(sqrt(1-rho2^2))));

		t2		= -.5*(((y1-x*beta1)/sigma1)^2);
		u2		= -.5*(((y1-x*beta2)/sigma2)^2);

		t3		= -ln(sqrt(2*pi)*sigma1) ;
		u3		= -ln(sqrt(2*pi)*sigma2) ;

	retp( 		
				(y2.==1).*(t1 + t2 + t3)
			+	(y2.==0).*(u1 + u2 + u3 )
		);
endp;


/* BINARY PROBIT PROCEDURE AND GRADIENT */
proc probit(b,dat);
	local 	y,x,p,dp;
		y	= dat[.,1];
		x	= dat[.,2:cols(dat)];
		p	= cdfn(x*b);
		dp	= p.>1e-18;
		p	= p.*dp+(1-dp)*1e-18;
	retp( y.*ln(p) + (1-y).*ln(1-p)  );
endp;

proc probitg(b,dat);
	local 	y,x,p,dp;
		y	= dat[.,1];
		x	= dat[.,2:cols(dat)];
		p	= cdfn(x*b);
		dp	= p.>1e-18;
		p	= p.*dp+(1-dp)*1e-18;
	retp( (y-p)./(p.*(1-p)).*pdfn(x*b).*x );
endp;


output off;
